@@ -589,6 +589,9 @@ void StyleDialog::OnStyleWebReport ( wxCommandEvent& event )
 	std::ofstream ofs ( tempNameUtf8.c_str() );
 	if ( !ofs )
 		return;
+
+	WrapExpat we;
+
 	ofs << XHTML_START;
 	ofs << "<body><h2>";
 	ofs << fileName.mb_str ( wxConvUTF8 );
@@ -606,15 +609,15 @@ void StyleDialog::OnStyleWebReport ( wxCommandEvent& event )
 		ofs << ++matchCount;
 		ofs << "</td>";
 		ofs << "<td align=\"right\">";
-		ofs << it->prelog;
+		ofs << we.xmliseTextNode ( it->prelog );
 		ofs << "</td><td align=\"center\"><font color=\"red\"><b>";
-		ofs << it->match;
+		ofs << we.xmliseTextNode ( it->match );
 		ofs << "</b></font></td><td align=\"left\">";
-		ofs << it->postlog;
+		ofs << we.xmliseTextNode ( it->postlog );
 		ofs << "</td><td><font color=\"green\"><b>";
-		ofs << it->replace;
+		ofs << we.xmliseTextNode ( it->replace );
 		ofs << "</b></font></td><td>";
-		ofs << it->report;
+		ofs << we.xmliseTextNode ( it->report );
 		ofs << "</td></tr>";
 	}
 	ofs << "</table></body>";
