@@ -53,6 +53,7 @@ XmlCtrl::XmlCtrl (
     const char *buffer, // could be NULL
     size_t bufferLen,
     const std::string& catalogPathParameter,
+    const std::string& catalogUtilityPathParameter,
     const std::string& basePathParameter,
     const std::string& auxPathParameter,
     const wxPoint& position,
@@ -62,6 +63,7 @@ XmlCtrl::XmlCtrl (
 		protectTags ( protectTagsParameter ),
 		visibilityState ( visibilityStateParameter ),
 		catalogPath ( catalogPathParameter ),
+		catalogUtilityPath ( catalogUtilityPathParameter ),
 		basePath ( basePathParameter ),
 		auxPath ( auxPathParameter )
 {
@@ -142,7 +144,6 @@ XmlCtrl::~XmlCtrl()
 	}
 	
 	delete validationReleasePtr;
-		
 }
 
 
@@ -244,7 +245,7 @@ void XmlCtrl::handleBackspace ( wxKeyEvent& event )
 
 	if ( canMoveLeftAt ( GetCurrentPos() ) )
 	{
-		event.Skip();
+		DeleteBack();//event.Skip();
 		return;
 	}
 
@@ -269,13 +270,13 @@ void XmlCtrl::handleBackspace ( wxKeyEvent& event )
 			if ( *protectTags )
 				adjustSelection();
 			else
-				event.Skip();
+				DeleteBack();//event.Skip();
 			return;
 		}
 		if ( !properties.deleteWholeTag )
 		{
 			if ( ! ( *protectTags ) )
-				event.Skip();
+				DeleteBack();//event.Skip();
 			return;
 		}
 		// delete tag to left of caret
@@ -352,7 +353,11 @@ void XmlCtrl::handleDelete ( wxKeyEvent& event )
 	end = GetSelectionEnd();
 	startLine = LineFromPosition ( start );
 	endLine = LineFromPosition ( end );
-	if ( startLine != endLine )
+	
+	// add test so range unindentation only happens when caret is flush with left margin
+	int column = GetColumn ( GetCurrentPos() );
+	
+	if ( startLine != endLine && !column)
 	{
 		if ( startLine > endLine )
 		{
@@ -398,13 +403,13 @@ void XmlCtrl::handleDelete ( wxKeyEvent& event )
 				if ( *protectTags )
 					adjustSelection();
 				else
-					event.Skip();
+					DeleteBack();//event.Skip();
 				return;
 			}
 			if ( !properties.deleteWholeTag )
 			{
 				if ( ! ( *protectTags ) )
-					event.Skip();
+					DeleteBack();//event.Skip();
 				return;
 			}
 
@@ -414,7 +419,7 @@ void XmlCtrl::handleDelete ( wxKeyEvent& event )
 			{
 				if ( limitPos > ( currentPos + BUFSIZ ) )
 				{
-					event.Skip();
+					DeleteBack();//event.Skip();
 					return;
 				}
 			}
@@ -445,7 +450,7 @@ void XmlCtrl::handleDelete ( wxKeyEvent& event )
 					break;
 				else if ( GetCharAt ( limitPos ) == '\n' || limitPos > ( currentPos + BUFSIZ ) )
 				{
-					event.Skip();
+					DeleteBack();//event.Skip();
 					return;
 				}
 			}
@@ -1439,7 +1444,7 @@ void XmlCtrl::setColorScheme ( int scheme )
 			SetCaretLineBackground ( baseBackground );
 
 			SetCaretForeground ( *wxBLACK );
-			SetSelBackground ( true, wxTheColourDatabase->Find ( _T ( "LIGHT GREY" ) ) );
+			SetSelBackground ( true,  LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 20));//wxTheColourDatabase->Find ( _T ( "LIGHT GREY" ) ) );
 
 			if ( type == FILE_TYPE_CSS )
 			{
@@ -1506,7 +1511,7 @@ void XmlCtrl::setColorScheme ( int scheme )
 			SetCaretLineBackground ( baseBackground );
 
 			SetCaretForeground ( *wxBLACK );
-			SetSelBackground ( true, wxTheColourDatabase->Find ( _T ( "LIGHT GREY" ) ) );
+			SetSelBackground ( true, LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 20) );//wxTheColourDatabase->Find ( _T ( "LIGHT GREY" ) ) );
 
 			if ( type == FILE_TYPE_CSS )
 			{
@@ -2063,6 +2068,8 @@ bool XmlCtrl::backgroundValidate (
 	validationThread = new ValidationThread(
 		buffer,
 		system,
+		catalogPath.c_str(),
+		catalogUtilityPath.c_str(),
 		&validationFinished,
 		&validationSuccess,
 		validationReleasePtr,
